@@ -20,6 +20,9 @@ def _fig_dimensions(kwargs):
     ):
         kwargs["frame_height"] = 275
 
+    if "toolbar_location" not in kwargs:
+        kwargs["toolbar_location"] = "above"
+
     return kwargs
 
 
@@ -53,7 +56,7 @@ def _parse_deprecations(q, q_axis, val, horizontal, horiz_q_axis):
     return q
 
 
-def _data_cats(data, q, cats, show_legend):
+def _data_cats(data, q, cats, show_legend, legend_label):
     if type(data) == xarray.core.dataarray.DataArray:
         if q is None:
             if data.name is None:
@@ -70,9 +73,12 @@ def _data_cats(data, q, cats, show_legend):
 
     if cats is None:
         data = data.copy()
-        data["__dummy_cat"] = " "
+        if legend_label is None:
+            data["__dummy_cat"] = " "
+            show_legend = False
+        else:
+            data["__dummy_cat"] = legend_label
         cats = "__dummy_cat"
-        show_legend = False
 
     return data, q, cats, show_legend
 
@@ -101,11 +107,11 @@ def _fill_between(p, x1=None, y1=None, x2=None, y2=None, **kwargs):
         Plot populated with fill-between.
 
     """
-    p.patch(
+    patch = p.patch(
         x=np.concatenate((x1, x2[::-1])), y=np.concatenate((y1, y2[::-1])), **kwargs
     )
 
-    return p
+    return p, patch
 
 
 def _get_marker(p, marker):
